package config_test

import (
	"github.com/stretchr/testify/assert"
	"testing"

	"gitea.deepak.science/deepak/gogmagog/config"
)

func TestSample(t *testing.T) {
	assert := assert.New(t)

	conf, err := config.GetConf("config-sample")
	assert.Nil(err)

	appConf := conf.App
	assert.Equal("devel", appConf.Environment)
	assert.Equal("5151", appConf.Port)
	assert.Equal("Africa/Abidjan", appConf.Timezone)

	dbConf := conf.Db
	assert.Equal("aoeu", dbConf.Type)
	assert.Equal("aeihn", dbConf.Host)
	assert.Equal("1234", dbConf.Port)
	assert.Equal("USER", dbConf.User)
	assert.Equal("PASSWORD", dbConf.Password)
	assert.Equal("g2", dbConf.Database)
	assert.True(dbConf.DropOnStart)
}

func TestDefault(t *testing.T) {
	assert := assert.New(t)

	conf, err := config.GetConf("config-missing-fields")
	assert.Nil(err)

	appConf := conf.App
	assert.Equal("missingfield", appConf.Environment)
	assert.Equal("8080", appConf.Port)
	assert.Equal("America/New_York", appConf.Timezone)

	dbConf := conf.Db
	assert.Equal("typical", dbConf.Type)
	assert.Equal("localhost", dbConf.Host)
	assert.Equal("5432", dbConf.Port)
	assert.Equal("<user>", dbConf.User)
	assert.Equal("<password>", dbConf.Password)
	assert.Equal("gogmagog", dbConf.Database)
	assert.False(dbConf.DropOnStart)
}

func TestMissingFile(t *testing.T) {
	assert := assert.New(t)

	conf, err := config.GetConf("non-existent")
	assert.Nil(conf)
	assert.NotNil(err)
}
