package models

import (
	"time"
)

// Plan represents a single day's agenda of actions.
type Plan struct {
	PlanID   int64      `json:"plan_id"`
	PlanDate *time.Time `json:"plan_date"`
	UserID   int64      `json:"user_id"`
}

// Plans returns all plans in the model.
func (m *Model) Plans(userID int) ([]*Plan, error) {
	return m.SelectPlans(userID)
}

// Plan returns a single plan from the store by plan_id.
func (m *Model) Plan(id int, userID int) (*Plan, error) {
	plan, err := m.SelectPlanByID(id, userID)
	return plan, wrapNotFound(err)
}

// AddPlan inserts a given plan into the store, returning the generated PlanID. The provided PlanID is ignored.
func (m *Model) AddPlan(plan *Plan, userID int) (int, error) {
	return m.InsertPlan(plan, userID)
}

// GetActions returns the actions associated with a particular plan.
func (m *Model) GetActions(plan *Plan, userID int) ([]*Action, error) {
	return m.SelectActionsByPlanID(plan, userID)
}
